@@ -10,11 +10,13 @@ pacman --noconfirm -S --needed \
     "${MINGW_PACKAGE_PREFIX}"-gobject-introspection \
     "${MINGW_PACKAGE_PREFIX}"-gtk3 \
     "${MINGW_PACKAGE_PREFIX}"-libffi \
+    "${MINGW_PACKAGE_PREFIX}"-meson \
+    "${MINGW_PACKAGE_PREFIX}"-ninja \
     "${MINGW_PACKAGE_PREFIX}"-python \
     "${MINGW_PACKAGE_PREFIX}"-python-cairo \
-    "${MINGW_PACKAGE_PREFIX}"-python-coverage \
     "${MINGW_PACKAGE_PREFIX}"-python-pip \
     "${MINGW_PACKAGE_PREFIX}"-python-pytest \
+    "${MINGW_PACKAGE_PREFIX}"-python-pytest-cov \
     "${MINGW_PACKAGE_PREFIX}"-toolchain \
     git \
     lcov
@@ -26,7 +28,6 @@ export CCACHE_BASEDIR="$(pwd)"
 export CCACHE_DIR="${CCACHE_BASEDIR}/_ccache"
 
 # coverage setup
-export CFLAGS="-coverage -ftest-coverage -fprofile-arcs -Werror"
 COV_DIR="$(pwd)/coverage"
 COV_KEY="${CI_JOB_NAME}"
 mkdir -p "${COV_DIR}"
@@ -35,15 +36,15 @@ export COVERAGE_FILE="${COV_DIR}/.coverage.${COV_KEY}"
 # https://docs.python.org/3/using/cmdline.html#envvar-PYTHONDEVMODE
 export PYTHONDEVMODE=1
 
-python setup.py build_tests
+
+MSYSTEM= CFLAGS="-coverage -ftest-coverage -fprofile-arcs -Werror" meson setup _build
 
 lcov \
     --config-file .gitlab-ci/lcovrc \
-    --directory "$(pwd)" \
-    --capture --initial --output-file \
+    --directory "$(pwd)" --capture --initial --output-file \
     "${COV_DIR}/${COV_KEY}-baseline.lcov"
 
-MSYSTEM= python -m coverage run --context "${COV_KEY}" tests/runtests.py
+MSYSTEM= PYTEST_ADDOPTS="--cov" meson test --suite pygobject --timeout-multiplier 4 -C _build -v
 MSYSTEM= python -m coverage lcov -o "${COV_DIR}/${COV_KEY}.py.lcov"
 
 lcov \
