@@ -34,6 +34,7 @@
 #include "pygi-error.h"
 #include "pygi-foreign.h"
 #include "pygi-resulttuple.h"
+#include "pygi-async.h"
 #include "pygi-source.h"
 #include "pygi-ccallback.h"
 #include "pygi-closure.h"
@@ -46,7 +47,6 @@
 #include "pygoptioncontext.h"
 #include "pygoptiongroup.h"
 #include "pygspawn.h"
-#include "pygparamspec.h"
 #include "pygpointer.h"
 #include "pygobject-internal.h"
 #include "pygi-value.h"
@@ -408,58 +408,20 @@ create_property (const gchar  *prop_name,
     return pspec;
 }
 
+static PyObject *
+pyg_param_spec_new (GParamSpec *pspec)
+{
+    PyErr_SetString (PyExc_NotImplementedError,
+                     "Creating ParamSpecs through pyg_param_spec_new is no longer supported");
+    return NULL;
+}
+
 static GParamSpec *
 pyg_param_spec_from_object (PyObject *tuple)
 {
-    Py_ssize_t val_length;
-    const gchar *prop_name;
-    GType prop_type;
-    const gchar *nick, *blurb;
-    PyObject *slice, *item, *py_prop_type;
-    GParamSpec *pspec;
-    gint intvalue;
-
-    val_length = PyTuple_Size(tuple);
-    if (val_length < 4) {
-	PyErr_SetString(PyExc_TypeError,
-			"paramspec tuples must be at least 4 elements long");
-	return NULL;
-    }
-
-    slice = PySequence_GetSlice(tuple, 0, 4);
-    if (!slice) {
-	return NULL;
-    }
-
-    if (!PyArg_ParseTuple(slice, "sOzz", &prop_name, &py_prop_type, &nick, &blurb)) {
-	Py_DECREF(slice);
-	return NULL;
-    }
-
-    Py_DECREF(slice);
-
-    prop_type = pyg_type_from_object(py_prop_type);
-    if (!prop_type) {
-	return NULL;
-    }
-
-    item = PyTuple_GetItem(tuple, val_length-1);
-    if (!PyLong_Check (item)) {
-	PyErr_SetString(PyExc_TypeError,
-			"last element in tuple must be an int");
-	return NULL;
-    }
-
-    if (!pygi_gint_from_py (item, &intvalue))
-	return NULL;
-
-    /* slice is the extra items in the tuple */
-    slice = PySequence_GetSlice(tuple, 4, val_length-1);
-    pspec = create_property(prop_name, prop_type,
-			    nick, blurb, slice,
-			    intvalue);
-
-    return pspec;
+    PyErr_SetString (PyExc_NotImplementedError,
+                     "Creating ParamSpecs through pyg_param_spec_from_object is no longer supported");
+    return NULL;
 }
 
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
@@ -922,7 +884,7 @@ pyg_object_set_property (GObject *object, guint property_id,
 	return;
     }
 
-    py_pspec = pyg_param_spec_new(pspec);
+    py_pspec = pygi_fundamental_new(pspec);
     py_value = pyg_value_as_pyobject (value, TRUE);
 
     retval = PyObject_CallMethod(object_wrapper, "do_set_property",
@@ -2263,7 +2225,7 @@ pyg_object_class_list_properties (PyObject *self, PyObject *args)
 	return NULL;
     }
     for (i = 0; i < nprops; i++) {
-	PyTuple_SetItem(list, i, pyg_param_spec_new(specs[i]));
+	PyTuple_SetItem(list, i, pygi_fundamental_new(specs[i]));
     }
     g_free(specs);
     if (class)
@@ -2298,6 +2260,18 @@ _wrap_pyig_pyos_getsig (PyObject *self, PyObject *args)
     return PyLong_FromVoidPtr ((void *)(PyOS_getsig (sig_num)));
 }
 
+static PyObject *
+_wrap_pyig_pyos_setsig (PyObject *self, PyObject *args)
+{
+    int sig_num;
+    PyObject *sig_handler;
+
+    if (!PyArg_ParseTuple (args, "iO!:pyos_setsig", &sig_num, &PyLong_Type, &sig_handler))
+        return NULL;
+
+    return PyLong_FromVoidPtr ((void *)(PyOS_setsig (sig_num, (PyOS_sighandler_t) PyLong_AsVoidPtr (sig_handler))));
+}
+
 static PyObject *
 _wrap_pygobject_new_full (PyObject *self, PyObject *args)
 {
@@ -2336,6 +2310,7 @@ static PyMethodDef _gi_functions[] = {
     { "variant_type_from_string", (PyCFunction) _wrap_pyg_variant_type_from_string, METH_VARARGS },
     { "source_new", (PyCFunction) pygi_source_new, METH_NOARGS },
     { "pyos_getsig", (PyCFunction) _wrap_pyig_pyos_getsig, METH_VARARGS },
+    { "pyos_setsig", (PyCFunction) _wrap_pyig_pyos_setsig, METH_VARARGS },
     { "source_set_callback", (PyCFunction) pygi_source_set_callback, METH_VARARGS },
     { "io_channel_read", (PyCFunction) pyg_channel_read, METH_VARARGS },
     { "require_foreign", (PyCFunction) pygi_require_foreign, METH_VARARGS | METH_KEYWORDS },
@@ -2372,6 +2347,8 @@ static struct PyGI_API CAPI = {
   pygi_register_foreign_struct,
 };
 
+const gpointer PyGParamSpec_Type_Stub = NULL;
+
 struct _PyGObject_Functions pygobject_api_functions = {
   pygobject_register_class,
   pygobject_register_wrapper,
@@ -2411,7 +2388,7 @@ struct _PyGObject_Functions pygobject_api_functions = {
   (PyGThreadBlockFunc)0, /* block_threads */
   (PyGThreadBlockFunc)0, /* unblock_threads */
 
-  &PyGParamSpec_Type,
+  (PyTypeObject *) &PyGParamSpec_Type_Stub,
   pyg_param_spec_new,
   pyg_param_spec_from_object,
 
@@ -2598,6 +2575,8 @@ _gi_exec (PyObject *module)
         return ret;
     if ((ret = pygi_resulttuple_register_types (module)) < 0)
         return ret;
+    if ((ret = pygi_async_register_types (module) < 0))
+        return ret;
 
     if ((ret = pygi_spawn_register_types (module_dict)) < 0)
         return ret;
@@ -2618,8 +2597,6 @@ _gi_exec (PyObject *module)
         return ret;
     if ((ret = pygi_interface_register_types (module_dict)) < 0)
         return ret;
-    if ((ret = pygi_paramspec_register_types (module_dict)) < 0)
-        return ret;
     if ((ret = pygi_enum_register_types (module_dict)) < 0)
         return ret;
     if ((ret = pygi_flags_register_types (module_dict)) < 0)
