@@ -21,7 +21,6 @@
 #include <Python.h>
 #include <girepository.h>
 
-#include "pygi-python-compat.h"
 #include "pygi-type.h"
 #include "pygi-info.h"
 #include "pygi-cache.h"
@@ -173,6 +172,11 @@ pygi_arg_interface_setup (PyGIInterfaceCache *iface_cache,
     iface_cache->g_type = g_registered_type_info_get_g_type ( (GIRegisteredTypeInfo *)iface_info);
     iface_cache->py_type = pygi_type_import_by_gi_info ( (GIBaseInfo *) iface_info);
 
+    if (g_type_is_a (iface_cache->g_type, G_TYPE_OBJECT)) {
+        if (g_str_equal (g_type_name (iface_cache->g_type), "GCancellable"))
+            iface_cache->arg_cache.async_context = PYGI_ASYNC_CONTEXT_CANCELLABLE;
+    }
+
     if (iface_cache->py_type == NULL) {
         return FALSE;
     }
@@ -662,7 +666,7 @@ _callable_cache_generate_args_cache_real (PyGICallableCache *callable_cache,
     arg_cache_item = callable_cache->to_py_args;
     while (arg_cache_item) {
         const gchar *arg_name = ((PyGIArgCache *)arg_cache_item->data)->arg_name;
-        PyObject *arg_string = PYGLIB_PyUnicode_FromString (arg_name);
+        PyObject *arg_string = PyUnicode_FromString (arg_name);
         PyList_Append (tuple_names, arg_string);
         Py_DECREF (arg_string);
         arg_cache_item = arg_cache_item->next;
@@ -788,8 +792,11 @@ _function_cache_invoke_real (PyGIFunctionCache *function_cache,
 static void
 _function_cache_deinit_real (PyGICallableCache *callable_cache)
 {
+    PyGIFunctionCache *function_cache = (PyGIFunctionCache *) callable_cache;
     g_function_invoker_destroy (&((PyGIFunctionCache *) callable_cache)->invoker);
 
+    Py_CLEAR (function_cache->async_finish);
+
     _callable_cache_deinit_real (callable_cache);
 }
 
@@ -800,6 +807,7 @@ _function_cache_init (PyGIFunctionCache *function_cache,
     PyGICallableCache *callable_cache = (PyGICallableCache *) function_cache;
     GIFunctionInvoker *invoker = &function_cache->invoker;
     GError *error = NULL;
+    guint i;
 
     callable_cache->calling_context = PYGI_CALLING_CONTEXT_IS_FROM_PY;
 
@@ -812,6 +820,76 @@ _function_cache_init (PyGIFunctionCache *function_cache,
     if (!_callable_cache_init (callable_cache, callable_info))
         return FALSE;
 
+    /* Check if this function is an async routine that is capable of returning
+     * an async awaitable object.
+     */
+    if (!callable_cache->has_return && callable_cache->n_to_py_args == 0) {
+        PyGIArgCache *cancellable = NULL;
+        PyGIArgCache *async_callback = NULL;
+
+        for (i = 0; i < _pygi_callable_cache_args_len (callable_cache); i++) {
+            PyGIArgCache *arg_cache = _pygi_callable_cache_get_arg (callable_cache, i);
+
+            /* Ignore any out or in/out parameters. */
+            if (arg_cache->async_context == PYGI_ASYNC_CONTEXT_CALLBACK) {
+                if (async_callback) {
+                    async_callback = NULL;
+                    break;
+                }
+                async_callback = arg_cache;
+            } else if (arg_cache->async_context == PYGI_ASYNC_CONTEXT_CANCELLABLE) {
+                if (cancellable) {
+                    cancellable = NULL;
+                    break;
+                }
+                cancellable = arg_cache;
+            }
+        }
+
+        if (cancellable && async_callback) {
+            GIBaseInfo *container = g_base_info_get_container ((GIBaseInfo*) callable_info);
+            GIBaseInfo *async_finish = NULL;
+            gint name_len;
+            gchar *finish_name = NULL;
+
+            /* This appears to be an async routine. As we have the
+             * GCallableInfo at this point, so guess the finish name and look
+             * up that information.
+             */
+            name_len = strlen (callable_cache->name);
+            if (g_str_has_suffix (callable_cache->name, "_async"))
+                name_len -= 6;
+
+            /* Original name without _async if it is there, _finish + NUL byte */
+            finish_name = g_malloc0 (name_len + 7 + 1);
+            strncat (finish_name, callable_cache->name, name_len);
+            strcat (finish_name, "_finish");
+
+            if (container && g_base_info_get_type (container) == GI_INFO_TYPE_OBJECT) {
+                async_finish = g_object_info_find_method ((GIObjectInfo *) container, finish_name);
+            } else if (container && g_base_info_get_type (container) == GI_INFO_TYPE_INTERFACE) {
+                async_finish = g_interface_info_find_method ((GIInterfaceInfo *) container, finish_name);
+            } else if (!container) {
+                async_finish = g_irepository_find_by_name (NULL,
+                                                           callable_cache->namespace,
+                                                           finish_name);
+            } else {
+                g_debug ("Awaitable async functions only work on GObjects and as toplevel functions.");
+            }
+
+            if (async_finish && g_base_info_get_type (async_finish)) {
+                function_cache->async_finish = _pygi_info_new ((GIBaseInfo *) async_finish);
+                function_cache->async_cancellable = cancellable;
+                function_cache->async_callback = async_callback;
+            }
+
+            if (async_finish)
+                g_base_info_unref (async_finish);
+
+            g_free (finish_name);
+        }
+    }
+
     /* Set by PyGICCallbackCache and PyGIVFuncCache */
     if (invoker->native_address == NULL) {
         if (g_function_info_prep_invoker ((GIFunctionInfo *) callable_info,
