@@ -104,12 +104,18 @@ typedef enum {
     PYGI_CALLING_CONTEXT_IS_FROM_PY
 } PyGICallingContext;
 
+typedef enum {
+    PYGI_ASYNC_CONTEXT_NONE = 0,
+    PYGI_ASYNC_CONTEXT_CALLBACK,
+    PYGI_ASYNC_CONTEXT_CANCELLABLE,
+} PyGIAsyncContext;
 
 struct _PyGIArgCache
 {
     const gchar *arg_name;
 
     PyGIMetaArgType meta_type;
+    PyGIAsyncContext async_context;
     gboolean is_pointer;
     gboolean is_caller_allocates;
     gboolean is_skipped;
@@ -218,6 +224,11 @@ struct _PyGICallableCache
 struct _PyGIFunctionCache {
     PyGICallableCache callable_cache;
 
+    /* Information about async functions. */
+    PyObject *async_finish;
+    PyGIArgCache *async_callback;
+    PyGIArgCache *async_cancellable;
+
     /* An invoker with ffi_cif already setup */
     GIFunctionInvoker invoker;
 
@@ -316,7 +327,10 @@ pygi_vfunc_cache_new        (GICallableInfo *info);
 PyGIClosureCache *
 pygi_closure_cache_new      (GICallableInfo *info);
 
-#define _pygi_callable_cache_args_len(cache) ((cache)->args_cache)->len
+inline static guint
+_pygi_callable_cache_args_len (PyGICallableCache *cache) {
+    return ((cache)->args_cache)->len;
+}
 
 inline static PyGIArgCache *
 _pygi_callable_cache_get_arg (PyGICallableCache *cache, guint index) {
