@@ -23,11 +23,11 @@
 #include "pygi-info.h"
 #include "pygi-cache.h"
 #include "pygi-invoke.h"
-#include "pygi-type.h"
 #include "pygi-argument.h"
 #include "pygi-util.h"
 #include "pygi-basictype.h"
 #include "pygi-type.h"
+#include "pygi-fundamental.h"
 
 /* _generate_doc_string
  *
@@ -560,6 +560,33 @@ _callable_info_call (PyGICallableInfo *self, PyObject *args, PyObject *kwargs)
     }
 }
 
+static PyObject *
+_callable_info_repr (PyGICallableInfo *self)
+{
+    PyObject *bound_repr_o = NULL;
+    const char *bound_repr = "None";
+    PyObject *res = NULL;
+
+    if (self->py_bound_arg) {
+        bound_repr_o = PyObject_Repr(self->py_bound_arg);
+        if (bound_repr_o == NULL)
+            goto out;
+
+        bound_repr = PyUnicode_AsUTF8(bound_repr_o);
+        if (bound_repr == NULL)
+            goto out;
+    }
+
+    res = PyUnicode_FromFormat ("%s(%s, bound=%s)",
+                                Py_TYPE( (PyObject *) self)->tp_name,
+                                _safe_base_info_get_name (self->base.info),
+                                bound_repr);
+
+out:
+    Py_XDECREF(bound_repr_o);
+
+    return res;
+}
 
 /* _function_info_call:
  *
@@ -1911,13 +1938,22 @@ _wrap_g_field_info_get_value (PyGIBaseInfo *self,
             pointer = pyg_boxed_get (instance, void);
             break;
         case GI_INFO_TYPE_OBJECT:
-            pointer = pygobject_get (instance);
+            if (pygi_check_fundamental (container_info_type, container_info))
+                pointer = pygi_fundamental_get (instance);
+            else
+                pointer = pygobject_get (instance);
             break;
         default:
             /* Other types don't have fields. */
             g_assert_not_reached();
     }
 
+    if (pointer == NULL) {
+        PyErr_Format(PyExc_RuntimeError, "object at %p of type %s is not initialized",
+                instance, Py_TYPE(instance)->tp_name);
+        return NULL;
+    }
+
     /* Get the field's value. */
     field_type_info = g_field_info_get_type ( (GIFieldInfo *) self->info);
 
@@ -2019,13 +2055,22 @@ _wrap_g_field_info_set_value (PyGIBaseInfo *self,
             pointer = pyg_boxed_get (instance, void);
             break;
         case GI_INFO_TYPE_OBJECT:
-            pointer = pygobject_get (instance);
+            if (pygi_check_fundamental (container_info_type, container_info))
+                pointer = pygi_fundamental_get (instance);
+            else
+                pointer = pygobject_get (instance);
             break;
         default:
             /* Other types don't have fields. */
             g_assert_not_reached();
     }
 
+    if (pointer == NULL) {
+        PyErr_Format(PyExc_RuntimeError, "object at %p of type %s is not initialized",
+                instance, Py_TYPE(instance)->tp_name);
+        return NULL;
+    }
+
     field_type_info = g_field_info_get_type ( (GIFieldInfo *) self->info);
 
     /* Set the field's value. */
@@ -2303,6 +2348,7 @@ pygi_info_register_types (PyObject *m)
     }
 
     PyGICallableInfo_Type.tp_call = (ternaryfunc) _callable_info_call;
+    PyGICallableInfo_Type.tp_repr = (reprfunc) _callable_info_repr;
     PyGICallableInfo_Type.tp_dealloc = (destructor) _callable_info_dealloc;
     _PyGI_REGISTER_TYPE (m, PyGICallableInfo_Type, CallableInfo,
                          PyGIBaseInfo_Type);
