@@ -31,14 +31,9 @@ pygi_arg_gobject_out_arg_from_py     (PyObject          *py_arg,     /* in */
                                       GITransfer         transfer);
 
 PyObject *
-pygi_arg_gobject_to_py               (GIArgument        *arg,
+pygi_arg_object_to_py_called_from_c  (GIArgument        *arg,
                                       GITransfer         transfer);
 
-PyObject *
-pygi_arg_gobject_to_py_called_from_c (GIArgument        *arg,
-                                      GITransfer         transfer);
-
-
 PyGIArgCache *
 pygi_arg_gobject_new_from_info       (GITypeInfo        *type_info,
                                       GIArgInfo         *arg_info,   /* may be null */
