@@ -20,6 +20,7 @@
 #include "pygi-value.h"
 #include "pygi-struct.h"
 #include "pygi-basictype.h"
+#include "pygi-fundamental.h"
 #include "pygobject-object.h"
 #include "pygi-type.h"
 #include "pygi-fundamental.h"
@@ -27,7 +28,6 @@
 #include "pygpointer.h"
 #include "pygboxed.h"
 #include "pygflags.h"
-#include "pygparamspec.h"
 
 
 /* glib 2.62 has started to print warnings for these which can't be disabled selectively, so just copy them here */
@@ -561,18 +561,6 @@ pyg_value_from_pyobject_with_error(GValue *value, PyObject *obj)
         }
         break;
     }
-    case G_TYPE_PARAM:
-        /* we need to support both the wrapped _gi.GParamSpec and the GI
-         * GObject.ParamSpec */
-        if (G_IS_PARAM_SPEC (pygobject_get (obj)))
-            g_value_set_param(value, G_PARAM_SPEC (pygobject_get (obj)));
-        else if (pyg_param_spec_check (obj))
-            g_value_set_param(value, PyCapsule_GetPointer (obj, NULL));
-        else {
-            PyErr_SetString(PyExc_TypeError, "Expected ParamSpec");
-            return -1;
-        }
-        break;
     case G_TYPE_OBJECT:
         if (obj == Py_None) {
             g_value_set_object(value, NULL);
@@ -792,8 +780,6 @@ value_to_py_structured_type (const GValue *value, GType fundamental, gboolean co
                         g_value_get_boxed(value),FALSE,FALSE);
         }
     }
-    case G_TYPE_PARAM:
-        return pyg_param_spec_new(g_value_get_param(value));
     case G_TYPE_OBJECT:
         return pygobject_new(g_value_get_object(value));
     case G_TYPE_VARIANT:
