@@ -1,13 +1,10 @@
-from __future__ import absolute_import
-
 import os
 import unittest
 
 try:
-    from gi.repository import Gtk, Atk, Gdk
+    from gi.repository import Gtk, Gdk
 except ImportError:
     Gdk = None
-    Atk = None
     Gtk = None
 
 from .helper import capture_glib_deprecation_warnings
@@ -24,6 +21,7 @@ def is_X11():
 
 
 @unittest.skipUnless(Gdk, 'Gdk not available')
+@unittest.skipIf(Gdk and Gdk._version == "4.0", 'Gdk4 doesn\'t have GdkAtom')
 class TestGdkAtom(unittest.TestCase):
     def test_create(self):
         atom = Gdk.Atom.intern('my_string', False)
@@ -96,5 +94,5 @@ class TestGdkAtom(unittest.TestCase):
             dm = display.get_device_manager()
             device = dm.get_client_pointer()
         axes = device.list_axes()
-        axes_names = [atom.name() for atom in axes]
-        self.assertNotEqual(axes_names, [])
+        axes_names = [atom.name() for atom in axes if atom is not None]
+        assert all(isinstance(name, str) for name in axes_names)
