@@ -459,11 +459,10 @@ class TestEverything(unittest.TestCase):
         self.assertEqual(Everything.test_enum_param(Everything.TestEnum.VALUE3), 'value3')
         self.assertRaises(TypeError, Everything.test_enum_param, 'hello')
 
-    # FIXME: ValueError: invalid enum value: 2147483648
-    @unittest.expectedFailure
+    @pytest.mark.xfail("32bit" in platform.architecture() or platform.system() == "Windows", reason="Big enum value doesn't convert to 32 bit (signed) long")
     def test_enum_unsigned(self):
         self.assertEqual(Everything.test_unsigned_enum_param(Everything.TestEnumUnsigned.VALUE1), 'value1')
-        self.assertEqual(Everything.test_unsigned_enum_param(Everything.TestEnumUnsigned.VALUE3), 'value3')
+        self.assertEqual(Everything.test_unsigned_enum_param(Everything.TestEnumUnsigned.VALUE2), 'value2')
         self.assertRaises(TypeError, Everything.test_unsigned_enum_param, 'hello')
 
     def test_flags(self):
@@ -619,6 +618,10 @@ class TestEverything(unittest.TestCase):
     def test_array_fixed_size_int_return(self):
         self.assertEqual(Everything.test_array_fixed_size_int_return(), [0, 1, 2, 3, 4])
 
+    def test_array_of_non_utf8_strings(self):
+        with pytest.raises(UnicodeDecodeError):
+            Everything.test_array_of_non_utf8_strings()
+
     def test_garray_container_return(self):
         # GPtrArray transfer container
         result = Everything.test_garray_container_return()
