@@ -1,7 +1,4 @@
 # -*- Mode: Python -*-
-# encoding: UTF-8
-
-from __future__ import absolute_import
 
 import os
 import unittest
